@@ -74,7 +74,6 @@ get_invcolor <- function(color){
 plot_pmx.individual <-
   function(x, dx, ...) {
     ID <- NULL
-    dx$isobserv <- TRUE
     dx$maxValue <- 0
     ## plot
     if (x$dname == "predictions") cat("USE predictions data set \n")
@@ -123,17 +122,26 @@ plot_pmx.individual <-
         }
       }
 
-      n <- ifelse(any(point$data$isobserv == "ignored"), 3, 2)
-      linetype_values <- c(rep("solid", n), "dashed")
-      if (any(point$data$isobserv == "ignored"))
-        linetype_labels <- c("accepted",
-                             "ignored",
-                             "individual predictions",
-                             "population predictions")
-      else
+      if (!is.null(point)) {
+        n <- ifelse(any(point$data$isobserv == "ignored"), 3, 2)
+        linetype_values <- c(rep("solid", n), "dashed")
+        if (any(point$data$isobserv == "ignored"))
+          linetype_labels <- c("accepted",
+                               "ignored",
+                               "individual predictions",
+                               "population predictions")
+        else
+          linetype_labels <- c("accepted",
+                               "individual predictions",
+                               "population predictions")
+
+      } else {
+        n <- 2
         linetype_labels <- c("accepted",
                              "individual predictions",
                              "population predictions")
+      }
+
 
       shape_values <- c(rep(point.shape, n + 1))
       shape_values_leg <- c(rep(point.shape, n - 1), rep(20, 2))
@@ -148,9 +156,7 @@ plot_pmx.individual <-
                            ipred_line$colour,
                            pred_line$colour)
       keywidth_values <- c(rep(0, n - 1), rep(2, 2))
-
-      p <-
-        ggplot(dx, aes(TIME, DV, shape = isobserv, colour = isobserv)) +
+      p <- ggplot(dx, aes(TIME, DV, shape=isobserv, colour=isobserv)) +
         p_point +
         geom_line(
           aes(
